@@ -121,7 +121,7 @@ QJSValue JsApi::JsonLd::newLodgingReservation() const
     return res;
 }
 
-QJSValue KItinerary::JsApi::JsonLd::newEventReservation() const
+QJSValue JsApi::JsonLd::newEventReservation() const
 {
     auto resFor = newObject(QStringLiteral("Event"));
     resFor.setProperty(QStringLiteral("location"), newPlace(QStringLiteral("Place")));
@@ -132,6 +132,40 @@ QJSValue KItinerary::JsApi::JsonLd::newEventReservation() const
     const auto ticket = newObject(QStringLiteral("Ticket"));
     res.setProperty(QStringLiteral("reservedTicket"), ticket);
 
+    const auto person = newObject(QStringLiteral("Person"));
+    res.setProperty(QStringLiteral("underName"), person);
+
+    return res;
+}
+
+QJSValue JsApi::JsonLd::newFoodEstablishmentReservation() const
+{
+    const auto person = newObject(QStringLiteral("Person"));
+    const auto resFor = newPlace(QStringLiteral("FoodEstablishment"));
+
+    auto res = newObject(QStringLiteral("FoodEstablishmentReservation"));
+    res.setProperty(QStringLiteral("reservationFor"), resFor);
+    res.setProperty(QStringLiteral("underName"), person);
+
+    return res;
+}
+
+QJSValue JsApi::JsonLd::newRentalCarReservation() const
+{
+    const auto pickup = newPlace(QStringLiteral("Place"));
+    const auto dropoff = newPlace(QStringLiteral("Place"));
+    const auto person = newObject(QStringLiteral("Person"));
+    const auto org = newObject(QStringLiteral("Organization"));
+
+    auto resFor = newObject(QStringLiteral("RentalCar"));
+    resFor.setProperty(QStringLiteral("rentalCompany"), org);
+
+    auto res = newObject(QStringLiteral("RentalCarReservation"));
+    res.setProperty(QStringLiteral("reservationFor"), resFor);
+    res.setProperty(QStringLiteral("pickupLocation"), pickup);
+    res.setProperty(QStringLiteral("dropoffLocation"), dropoff);
+    res.setProperty(QStringLiteral("underName"), person);
+
     return res;
 }
 
@@ -211,6 +245,32 @@ QDateTime JsApi::JsonLd::toDateTime(const QString &dtStr, const QString &format,
     return dt;
 }
 
+QDateTime JsApi::JsonLd::toDateTime(const QString &dtStr, const QJSValue &format, const QJSValue &localeName) const
+{
+    if (localeName.isString() && format.isString()) {
+        return toDateTime(dtStr, format.toString(), localeName.toString());
+    }
+    if (format.isArray()) {
+        const auto count = format.property(QLatin1String("length")).toInt();
+        for (auto i = 0; i < count; ++i) {
+            const auto dt = toDateTime(dtStr, format.property(i), localeName);
+            if (dt.isValid()) {
+                return dt;
+            }
+        }
+    }
+    if (format.isString() && localeName.isArray()) {
+        const auto count = localeName.property(QLatin1String("length")).toInt();
+        for (auto i = 0; i < count; ++i) {
+            const auto dt = toDateTime(dtStr, format.toString(), localeName.property(i).toString());
+            if (dt.isValid()) {
+                return dt;
+            }
+        }
+    }
+    return {};
+}
+
 QJSValue JsApi::JsonLd::toJson(const QVariant &v) const
 {
     if (v.canConvert<QVector<QVariant>>()) {
